==> nomachine-7.8.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXUser.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXUser::BEGIN{package NXUser;no warnings;require Exception::Internal;do{
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
import};}sub NXUser::BEGIN{package NXUser;no warnings;require 
Exception::NXUser::NXUserCannotBeUserNX;do{
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x4e\x58\x55\x73\x65\x72\x3a\x3a\x4e\x58\x55\x73\x65\x72\x43\x61\x6e\x6e\x6f\x74\x42\x65\x55\x73\x65\x72\x4e\x58"
->import};}sub NXUser::BEGIN{package NXUser;no warnings;require 
Exception::NXUser::NXCannotLoginByAdministrator;do{
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x4e\x58\x55\x73\x65\x72\x3a\x3a\x4e\x58\x43\x61\x6e\x6e\x6f\x74\x4c\x6f\x67\x69\x6e\x42\x79\x41\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72"
->import};}sub NXUser::new{package NXUser;no warnings;(my ($login,$password,
$service)=@_);if ((not (defined ($login)))){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw (
"\x70\x61\x72\x61\x6d\x65\x74\x65\x72\x20\x27\x6c\x6f\x67\x69\x6e\x27\x20\x63\x61\x6e\x6e\x6f\x74\x20\x62\x65\x20\x6e\x75\x6c\x6c"
);}if ((length ($login)==(0x0056+ 6221-0x18a3))){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw (
"\x70\x61\x72\x61\x6d\x65\x74\x65\x72\x20\x27\x6c\x6f\x67\x69\x6e\x27\x20\x63\x61\x6e\x6e\x6f\x74\x20\x62\x65\x20\x65\x6d\x70\x74\x79"
);}if ((not (defined ($password)))){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw (
"\x70\x61\x72\x61\x6d\x65\x74\x65\x72\x20\x27\x70\x61\x73\x73\x77\x6f\x72\x64\x27\x20\x63\x61\x6e\x6e\x6f\x74\x20\x62\x65\x20\x6e\x75\x6c\x6c"
);}if (($GLOBAL::LOGGED_USER ne (""))){(my $loggedUid=
Common::NXCore::userInfoGetUidByUsername ($GLOBAL::LOGGED_USER));(my $newUserUid
=Common::NXCore::userInfoGetUidByUsername ($login));if (($loggedUid ne 
$newUserUid)){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw (
"\x70\x61\x72\x61\x6d\x65\x74\x65\x72\x20\x27\x6c\x6f\x67\x69\x6e\x27\x20\x69\x73\x20\x69\x6e\x63\x6f\x72\x72\x65\x63\x74"
);}}($login=NXLogin::getAbsoluteNameForUsernameIfNotDisabled ($login));if ((((((
(($service ne 
"\x63\x68\x65\x63\x6b\x4c\x6f\x63\x61\x6c\x53\x65\x73\x73\x69\x6f\x6e")and (
$service ne "\x61\x73\x6b\x34\x61\x74\x74\x61\x63\x68"))and ($service ne 
"\x72\x65\x6d\x6f\x74\x65\x4e\x6f\x64\x65"))and ($service ne 
"\x72\x75\x6e\x4e\x78\x4d\x6f\x6e\x69\x74\x6f\x72"))and ($service ne 
"\x67\x65\x74\x50\x6c\x61\x74\x66\x6f\x72\x6d"))and ($service ne 
"\x67\x65\x74\x55\x75\x69\x64"))and ($service ne 
"\x67\x65\x74\x52\x65\x73\x6f\x75\x72\x63\x65\x6c\x69\x73\x74"))){(my $nxUserUid
=Common::NXCore::userInfoGetUidByUsername ("\x6e\x78"));(my $newUserUid=
Common::NXCore::userInfoGetUidByUsername ($login));if ((($login eq "\x6e\x78")or
 ($nxUserUid eq $newUserUid))){($password="\x58\x58\x58\x58\x58\x58");
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x4e\x58\x55\x73\x65\x72\x3a\x3a\x4e\x58\x55\x73\x65\x72\x43\x61\x6e\x6e\x6f\x74\x42\x65\x55\x73\x65\x72\x4e\x58"
->throw ($login);}if (($GLOBAL::EnableAdministratorLogin ne "\x31")){if (
NXAdministratorsManager::userIsAdministrator ($login)){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x4e\x58\x55\x73\x65\x72\x3a\x3a\x4e\x58\x43\x61\x6e\x6e\x6f\x74\x4c\x6f\x67\x69\x6e\x42\x79\x41\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72"
->throw ($login);}}}(my (%hash)=());($hash{"\x6c\x6f\x67\x69\x6e"}=$login);(
$hash{"\x70\x61\x73\x73\x77\x6f\x72\x64"}=$password);(my $self=(\%hash));bless (
$self);return ($self);}sub NXUser::getLogin{package NXUser;no warnings;(my $self
=shift (@_));return ($$self{"\x6c\x6f\x67\x69\x6e"});}sub NXUser::getPassword{
package NXUser;no warnings;(my $self=shift (@_));return ($$self{
"\x70\x61\x73\x73\x77\x6f\x72\x64"});}package NXUser;no warnings;return (
(0x0c60+ 6625-0x2640));

==> nomachine-7.9.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXUser.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXUser::BEGIN{package NXUser;no warnings;require Exception::Internal;do{
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
import};}sub NXUser::BEGIN{package NXUser;no warnings;require 
Exception::NXUser::NXUserCannotBeUserNX;do{
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x4e\x58\x55\x73\x65\x72\x3a\x3a\x4e\x58\x55\x73\x65\x72\x43\x61\x6e\x6e\x6f\x74\x42\x65\x55\x73\x65\x72\x4e\x58"
->import};}sub NXUser::BEGIN{package NXUser;no warnings;require 
Exception::NXUser::NXCannotLoginByAdministrator;do{
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x4e\x58\x55\x73\x65\x72\x3a\x3a\x4e\x58\x43\x61\x6e\x6e\x6f\x74\x4c\x6f\x67\x69\x6e\x42\x79\x41\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72"
->import};}sub NXUser::new{package NXUser;no warnings;(my ($login,$password,
$service)=@_);if ((not (defined ($login)))){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw (
"\x70\x61\x72\x61\x6d\x65\x74\x65\x72\x20\x27\x6c\x6f\x67\x69\x6e\x27\x20\x63\x61\x6e\x6e\x6f\x74\x20\x62\x65\x20\x6e\x75\x6c\x6c"
);}if ((length ($login)==(0x044d+ 2771-0x0f20))){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw (
"\x70\x61\x72\x61\x6d\x65\x74\x65\x72\x20\x27\x6c\x6f\x67\x69\x6e\x27\x20\x63\x61\x6e\x6e\x6f\x74\x20\x62\x65\x20\x65\x6d\x70\x74\x79"
);}if ((not (defined ($password)))){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw (
"\x70\x61\x72\x61\x6d\x65\x74\x65\x72\x20\x27\x70\x61\x73\x73\x77\x6f\x72\x64\x27\x20\x63\x61\x6e\x6e\x6f\x74\x20\x62\x65\x20\x6e\x75\x6c\x6c"
);}if (($GLOBAL::LOGGED_USER ne (""))){(my $loggedUid=
Common::NXCore::userInfoGetUidByUsername ($GLOBAL::LOGGED_USER));(my $newUserUid
=Common::NXCore::userInfoGetUidByUsername ($login));if (($loggedUid ne 
$newUserUid)){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw (
"\x70\x61\x72\x61\x6d\x65\x74\x65\x72\x20\x27\x6c\x6f\x67\x69\x6e\x27\x20\x69\x73\x20\x69\x6e\x63\x6f\x72\x72\x65\x63\x74"
);}}($login=NXLogin::getAbsoluteNameForUsernameIfNotDisabled ($login));if ((((((
(($service ne 
"\x63\x68\x65\x63\x6b\x4c\x6f\x63\x61\x6c\x53\x65\x73\x73\x69\x6f\x6e")and (
$service ne "\x61\x73\x6b\x34\x61\x74\x74\x61\x63\x68"))and ($service ne 
"\x72\x65\x6d\x6f\x74\x65\x4e\x6f\x64\x65"))and ($service ne 
"\x72\x75\x6e\x4e\x78\x4d\x6f\x6e\x69\x74\x6f\x72"))and ($service ne 
"\x67\x65\x74\x50\x6c\x61\x74\x66\x6f\x72\x6d"))and ($service ne 
"\x67\x65\x74\x55\x75\x69\x64"))and ($service ne 
"\x67\x65\x74\x52\x65\x73\x6f\x75\x72\x63\x65\x6c\x69\x73\x74"))){(my $nxUserUid
=Common::NXCore::userInfoGetUidByUsername ("\x6e\x78"));(my $newUserUid=
Common::NXCore::userInfoGetUidByUsername ($login));if ((($login eq "\x6e\x78")or
 ($nxUserUid eq $newUserUid))){($password="\x58\x58\x58\x58\x58\x58");
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x4e\x58\x55\x73\x65\x72\x3a\x3a\x4e\x58\x55\x73\x65\x72\x43\x61\x6e\x6e\x6f\x74\x42\x65\x55\x73\x65\x72\x4e\x58"
->throw ($login);}if (($GLOBAL::EnableAdministratorLogin ne "\x31")){if (
NXAdministratorsManager::userIsAdministrator ($login)){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x4e\x58\x55\x73\x65\x72\x3a\x3a\x4e\x58\x43\x61\x6e\x6e\x6f\x74\x4c\x6f\x67\x69\x6e\x42\x79\x41\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72"
->throw ($login);}}}(my (%hash)=());($hash{"\x6c\x6f\x67\x69\x6e"}=$login);(
$hash{"\x70\x61\x73\x73\x77\x6f\x72\x64"}=$password);(my $self=(\%hash));bless (
$self);return ($self);}sub NXUser::getLogin{package NXUser;no warnings;(my $self
=shift (@_));return ($$self{"\x6c\x6f\x67\x69\x6e"});}sub NXUser::getPassword{
package NXUser;no warnings;(my $self=shift (@_));return ($$self{
"\x70\x61\x73\x73\x77\x6f\x72\x64"});}package NXUser;no warnings;return (
(0x07af+ 4451-0x1911));
